@@ -854,10 +854,10 @@ print.summary.meta <- function(x,
   chklogical(print.I2)
   chklogical(print.H)
   chklogical(print.Rb)
-  chkchar(text.tau2)
-  chkchar(text.tau)
-  chkchar(text.I2)
-  chkchar(text.Rb)
+  chkchar(text.tau2, length = 1)
+  chkchar(text.tau, length = 1)
+  chkchar(text.I2, length = 1)
+  chkchar(text.Rb, length = 1)
   chklogical(warn.backtransf)
   is.prop <- is.prop(x$sm)
   is.rate <- is.rate(x$sm)
